@@ -2,18 +2,18 @@ import asyncio
 import time
 from asyncio import Task
 from typing import Optional, Union, List
-from cesloi.context import enter_message_send_context, UploadMethods, bot_application_context_manager, upload_method
+from cesloi.utils import enter_message_send_context, UploadMethods, bot_application_context_manager, upload_method
 from cesloi.delegatesystem import EventDelegate
 from cesloi.delegatesystem.entities.subsciber import SubscriberHandler
 from cesloi.event.lifecycle import ApplicationRunning
 from cesloi.event.messages import Message, GroupMessage, FriendMessage, TempMessage
 from cesloi.logger import Logger
 from cesloi.communicate_with_mah import BotSession, Communicator
-from cesloi.message import BotMessage, Profile
+from cesloi.model.utils import BotMessage, Profile, FileInfo
 from cesloi.message.element import Source, MessageElement
-from cesloi.message import Friend
-from cesloi.message.group import Group, Member, GroupConfig, MemberInfo
+from cesloi.model.relation import Group, Member, GroupConfig, MemberInfo, Friend
 from cesloi.message.messageChain import MessageChain
+from cesloi.plugin import Bellidin
 
 
 class Cesloi:
@@ -21,14 +21,16 @@ class Cesloi:
             self,
             *,
             bot_session: BotSession,
+            delegate: Optional[EventDelegate] = None,
             logger: Optional[Logger] = None,
             debug: bool = False,
             enable_chat_log: bool = True,
     ):
-        self.delegate: EventDelegate = EventDelegate()
+        self.delegate: EventDelegate = delegate or EventDelegate()
         self.bot_session: BotSession = bot_session
         self.debug = debug
-        self.logger = logger or Logger(level='debug' if debug else 'info')
+        self.logger = logger or Logger(level='DEBUG' if debug else 'INFO').logger
+        self.bellidin = Bellidin.set_bellidin(self.delegate,self.logger)
         self.chat_log_enabled = enable_chat_log
         self.communicator = Communicator(bot_session, bot=self, delegate=self.delegate, logger=self.logger)
         self.running: bool = False
@@ -93,9 +95,9 @@ class Cesloi:
                     if self.communicator.running_task:
                         await self.communicator.running_task
                 except Exception as e:
-                    self.logger.warn(e)
+                    self.logger.warning(e)
                 await self.communicator.stop()
-                self.logger.warn("Communicator stopped")
+                self.logger.warning("Communicator stopped")
                 await asyncio.sleep(retry_interval)
                 self.logger.info("Cesloi Network Restarting...")
             except asyncio.CancelledError:
@@ -105,6 +107,7 @@ class Cesloi:
     async def close(self):
         if self.running:
             self.running = False
+            self.uninstall_plugins()
             if self.daemon_task:
                 self.daemon_task.cancel()
                 self.daemon_task = None
@@ -133,7 +136,7 @@ class Cesloi:
             if self.daemon_task:
                 loop.run_until_complete(self.daemon_task)
         except KeyboardInterrupt or asyncio.CancelledError:
-            self.logger.warn("Interrupt detected, bot stopping ...")
+            self.logger.warning("Interrupt detected, bot stopping ...")
         loop.run_until_complete(self.close())
 
     def register(self, *args, **kwargs):
@@ -142,6 +145,24 @@ class Cesloi:
         """
         return self.delegate.register(*args, **kwargs)
 
+    def install_plugins(self, plugins_dir: str):
+        """
+        导入插件方法，必须传入一个目录，目录内有你的.py文件或模块
+        """
+        return self.bellidin.install_plugins(plugins_dir)
+
+    def uninstall_plugins(self):
+        """
+        卸载导入的插件的方法.
+        """
+        return self.bellidin.uninstall_plugins()
+
+    def reload_plugins(self, new_plugins_dir: Optional[str] = None):
+        """
+        重载插件方法，可选传入一个新目录，目录内有你的.py文件或模块
+        """
+        return self.bellidin.reload_plugins(new_plugins_dir)
+
     async def get_mah_version(self):
         result = await self.communicator.send_handle("about", "GET")
         return result['version']
@@ -692,7 +713,7 @@ class Cesloi:
     async def upload_image(self, data: bytes, may_method: Optional[str] = None, is_flash: bool = False):
         from .message.element import Image
         from .message.element import FlashImage
-        method = may_method or upload_method.get()
+        method = may_method or upload_method.get().value
         result = await self.communicator.send_handle(
             "uploadIamge",
             "MULIPART",
@@ -708,7 +729,7 @@ class Cesloi:
 
     async def upload_voice(self, data: bytes, may_method: Optional[str] = None):
         from .message.element import Voice
-        method = may_method or upload_method.get()
+        method = may_method or upload_method.get().value
         if method == "group":
             result = await self.communicator.send_handle(
                 "uploadVoice",
@@ -722,3 +743,157 @@ class Cesloi:
             return Voice.parse_obj(result)
         else:
             raise TypeError("Voice is only provides sending in group!")
+
+    async def upload_file(self, data: bytes, target: Union[Group, int], may_method: Optional[str] = None,
+                          path: str = "", ):
+        method = may_method or upload_method.get().value
+        if method == "group":
+            result = await self.communicator.send_handle(
+                "file/upload",
+                "MULTIPART",
+                {
+                    "sessionKey": self.bot_session.sessionKey,
+                    "type": method.value,
+                    "target": target if isinstance(target, int) else target.id,
+                    "path": path,
+                    "file": data,
+                },
+            )
+            return FileInfo.parse_obj(result)
+        else:
+            raise TypeError("File is only provides sending in group!")
+
+    async def file_get_list(self, target: Union[Group, int], dir_id: str = "", with_download_info: bool = False,
+                            offset: Optional[int] = 0, size: Optional[int] = 1):
+        """
+        列出指定文件夹下的所有文件.
+
+        Args:
+           target (Union[Group, int]): 目标文件的群号
+           dir_id (str): 文件ID, 空串为根目录
+           with_download_info (bool): 是否携带下载信息, 无必要不要携带
+           offset (int): 分页偏移
+           size (int): 分页大小
+        Returns:
+           FileInfo: 返回的文件信息列表.
+        """
+
+        result = await self.communicator.send_handle(
+            "file/list",
+            "GET",
+            {
+                "sessionKey": self.bot_session.sessionKey,
+                "id": dir_id,
+                "target": target.id if isinstance(target, Group) else target,
+                "withDownloadInfo": str(with_download_info),
+                "offset": offset,
+                "size": size
+            },
+        )
+
+        return [FileInfo.parse_obj(i) for i in result]
+
+    async def file_get_info(self, target: Union[Group, int], dir_id: str = "", with_download_info: bool = False):
+        """
+        获取指定文件的信息.
+
+        Args:
+           target (Union[Group, int]): 目标文件的群号
+           dir_id (str): 文件ID, 空串为根目录
+           with_download_info (bool): 是否携带下载信息, 无必要不要携带
+        Returns:
+           FileInfo: 返回的文件信息.
+        """
+
+        result = await self.communicator.send_handle(
+            "file/list",
+            "GET",
+            {
+                "sessionKey": self.bot_session.sessionKey,
+                "id": dir_id,
+                "target": target.id if isinstance(target, Group) else target,
+                "withDownloadInfo": str(with_download_info)
+            },
+        )
+        return FileInfo.parse_obj(result)
+
+    async def file_make_directory(self, target: Union[Group, int], directory_name: str, dir_id: str = ""):
+        """
+        在指定位置创建新文件夹.
+
+        Args:
+            target (Union[Group, int]): 目标文件的群号
+            directory_name (str): 新建文件夹名.
+            dir_id (str): 父目录id,空串为根目录
+        Returns:
+            FileInfo: 新创建文件夹的信息.
+        """
+        result = await self.communicator.send_handle(
+            "file/list",
+            "POST",
+            {
+                "sessionKey": self.bot_session.sessionKey,
+                "id": dir_id,
+                "directoryName": directory_name,
+                "target": target.id if isinstance(target, Group) else target,
+            },
+        )
+        return FileInfo.parse_obj(result)
+
+    async def file_delete(self, target: Union[Group, int], dir_id: str = ""):
+        """
+        删除指定文件.
+
+        Args:
+           target (Union[Group, int]): 目标文件的群号
+           dir_id (str): 删除文件的id
+        """
+        await self.communicator.send_handle(
+            "file/delete",
+            "POST",
+            {
+                "sessionKey": self.bot_session.sessionKey,
+                "id": dir_id,
+                "target": target.id if isinstance(target, Group) else target,
+            },
+        )
+
+    async def file_move(self, target: Union[Group, int], move_to: str, dir_id: str = ""):
+        """
+        移动指定文件.
+
+        Args:
+           target (Union[Group, int]): 目标文件的群号
+           move_to (str): 移动目标文件夹的id
+           dir_id (str): 移动文件的id
+        """
+        await self.communicator.send_handle(
+            "file/move",
+            "POST",
+            {
+                "sessionKey": self.bot_session.sessionKey,
+                "id": dir_id,
+                "target": target.id if isinstance(target, Group) else target,
+                "moveTo": move_to
+            },
+        )
+
+    async def file_rename(self, target: Union[Group, int], rename_to: str, dir_id: str = ""):
+        """
+        重命名指定文件.
+
+        Args:
+           target (Union[Group, int]): 目标文件的群号
+           rename_to (str): 新文件名
+           dir_id (str): 重命名文件id
+        """
+        await self.communicator.send_handle(
+            "file/rename",
+            "POST",
+            {
+                "sessionKey": self.bot_session.sessionKey,
+                "id": dir_id,
+                "target": target.id if isinstance(target, Group) else target,
+                "renameTO": rename_to
+            },
+        )
