@@ -8,7 +8,7 @@ from pydantic import BaseModel, AnyHttpUrl, Extra
 from typing import Optional, Union, Dict, TYPE_CHECKING
 from aiohttp import ClientSession, WSMsgType
 
-from cesloi.context import enter_context
+from cesloi.utils import enter_context
 from cesloi.delegatesystem import EventDelegate
 from cesloi.logger import Logger
 from yarl import URL
@@ -79,7 +79,7 @@ class Communicator:
     bot_session: BotSession
     delegate: EventDelegate
     loop: asyncio.AbstractEventLoop
-    logger: Logger
+    logger: Logger.logger
 
     def __init__(
             self,
@@ -91,7 +91,7 @@ class Communicator:
         self.bot_session = bot_session
         self.delegate = delegate
         self.loop = delegate.loop
-        self.logger = logger or Logger()
+        self.logger = logger or Logger().logger
         self.bot = bot
         self.running_task: Optional[Task] = None
         self.running: bool = False
@@ -178,7 +178,7 @@ class Communicator:
                     self.delegate.handle_event(event)
             else:
                 if sync_id not in self.wait_response_future:
-                    self.logger.warn(f"syncId {sync_id} not found!")
+                    self.logger.warning(f"syncId {sync_id} not found!")
                 else:
                     self.wait_response_future.pop(sync_id).set_result(data)
 
@@ -207,7 +207,7 @@ class Communicator:
                     ws_message = await connection.receive()
                 except asyncio.TimeoutError:
                     if ping_count > 5:
-                        self.logger.warn("websocket: timeout,stop")
+                        self.logger.warning("websocket: timeout,stop")
                         await self.stop()
                     else:
                         await self.ws_connection.ping()
@@ -239,9 +239,9 @@ class Communicator:
                 elif ws_message.type is WSMsgType.PONG:
                     self.logger.debug("websocket: received pong from remote")
                 elif ws_message.type == WSMsgType.ERROR:
-                    self.logger.warn("websocket: connection error: " + ws_message.data)
+                    self.logger.warning("websocket: connection error: " + ws_message.data)
                 else:
-                    self.logger.warn(f"detected a unknown message type: {ws_message.type}")
+                    self.logger.warning(f"detected a unknown message type: {ws_message.type}")
         self.logger.info("connection disconnected")
 
     async def connect(self):
