@@ -1,6 +1,7 @@
 import asyncio
 import traceback
-from typing import List, Union, Type, Dict, Any
+import time
+from typing import List, Union, Type, Dict, Any, Optional
 from .entities.event import TemplateEvent
 from .entities.publisher import Publisher
 from .entities.subsciber import SubscriberHandler
@@ -9,10 +10,14 @@ from .entities.subsciber import SubscriberHandler
 class EventDelegate:
     loop: asyncio.AbstractEventLoop
     publisher_list: List[Publisher]
+    safe_interval: float
 
-    def __init__(self):
-        self.loop = asyncio.get_event_loop()
+    def __init__(self, loop: Optional[asyncio.AbstractEventLoop] = None, interval: Optional[float] = None):
+        self.loop = loop or asyncio.get_event_loop()
         self.publisher_list = []
+        self.safe_interval = interval or 0.001
+        self.init_time = time.time()
+        self.last_time = self.init_time
 
     def parse_to_event(self, event_dict: Dict[str, Any]):
         examine_event = self.search_event(event_dict.get('type')).parse_obj(
@@ -20,11 +25,14 @@ class EventDelegate:
         return examine_event
 
     def handle_event(self, event: TemplateEvent):
-        self.loop.create_task(
-            self.exec_subscriber(
-                publisher=self.search_publisher(event.__class__),
-                event=event)
-        )
+        current_time = time.time()
+        if current_time - self.last_time > self.safe_interval:
+            self.loop.create_task(
+                self.exec_subscriber(
+                    publisher=self.search_publisher(event.__class__),
+                    event=event)
+            )
+        self.last_time = current_time
 
     async def exec_subscriber(self, publisher: Publisher, event: TemplateEvent):
         from ..event.messages import Message
@@ -33,7 +41,7 @@ class EventDelegate:
                 self.get_coroutine_executable_target(
                     target,
                     event.get_params(target.params),  # 执行事件内的参数解析方法，获取可能的函数需要的实际参数
-                    message=event.messageChain if isinstance(event, Message) else ""  # 获取可能的消息链
+                    event.messageChain if isinstance(event, Message) else ""  # 获取可能的消息链
                 ) for target in publisher.subscribers
             ]
             results, _ = await asyncio.wait(coroutine)
@@ -43,7 +51,11 @@ class EventDelegate:
 
     @staticmethod
     async def get_coroutine_executable_target(target, real_arguments, message):
-        if SubscriberHandler.command_handler(target, message)[0]:  # subscriber的command/time处理
+        # subscriber的command/time处理
+        command_result = SubscriberHandler.command_handler(target, message)
+        if command_result[0]:
+            # 参数替换的处理
+            real_arguments = SubscriberHandler.params_handler(target, real_arguments, command_result[1], message)
             try:
                 result = await target.callable_target(**real_arguments)
             except Exception as e:
