@@ -1,4 +1,4 @@
-from typing import List, Type
+from typing import List, Type, Union
 
 from pydantic import BaseModel
 
@@ -24,3 +24,12 @@ class Publisher(PublisherInterface):
 
     def subscribers_names(self):
         return [i.name for i in self.subscribers]
+
+    def remove_subscriber(self, target: Union[str, Subscriber]):
+        if isinstance(target, Subscriber):
+            self.subscribers.pop(self.subscribers.index(target))
+        for i in range(0, len(self.subscribers)):
+            if self.subscribers[i].name == target:
+                self.subscribers.pop(i)
+                break
+
