@@ -1,5 +1,5 @@
 from cesloi.delegatesystem.entities.paramsInserter import TemplateParamsInserter
-from cesloi.context import bot_application, event
+from cesloi.utils import bot_application, event
 
 
 class ApplicationInserter(TemplateParamsInserter):
