@@ -1,18 +1,38 @@
 import json as JSON
+from xml import sax
 from enum import Enum
 from pathlib import Path
-from typing import Dict, Optional, TYPE_CHECKING, Union
+from typing import Dict, Optional, TYPE_CHECKING, Union, List
 from base64 import b64decode, b64encode
-from ..context import bot_application
+from ..utils import bot_application
 import aiohttp
 from pydantic import BaseModel, validator, Field, BaseConfig, Extra
 from abc import ABC, abstractmethod
+
 if TYPE_CHECKING:
     from .messageChain import MessageChain
     from pydantic.typing import AbstractSetIntStr, MappingIntStrAny, DictStrAny
 
 
 class ElementModel(BaseModel):
+
+    def dict(
+            self,
+            *,
+            include: Union["AbstractSetIntStr", "MappingIntStrAny"] = None,
+            exclude: Union["AbstractSetIntStr", "MappingIntStrAny"] = None,
+            by_alias: bool = False,
+            skip_defaults: bool = None,
+            exclude_unset: bool = False,
+            exclude_defaults: bool = False,
+            exclude_none: bool = False,
+    ) -> "DictStrAny":
+        return super().dict(
+            by_alias=True,
+            exclude=exclude,
+            exclude_none=True
+        )
+
     class Config(BaseConfig):
         extra = Extra.allow
 
@@ -23,12 +43,10 @@ class MessageElement(ABC, ElementModel):
     def __hash__(self):
         return hash((type(self),) + tuple(self.__dict__.values()))
 
-    @abstractmethod
     def to_serialization(self) -> str:
-        """将元素转为可序列化的字符串"""
+        return f"[mirai:{self.type}:{JSON.dumps(self.dict(exclude={'type'}))}]"
 
     @staticmethod
-    @abstractmethod
     def from_json(json: Dict):
         """将json转换为元素"""
 
@@ -52,9 +70,6 @@ class MediaElement(MessageElement):
         if self.base64:
             return b64decode(self.base64)
 
-    def dict(self, *, include: Union['AbstractSetIntStr', 'MappingIntStrAny'] = None, exclude: Union['AbstractSetIntStr', 'MappingIntStrAny'] = None, by_alias: bool = False, skip_defaults: bool = None, exclude_unset: bool = False, exclude_defaults: bool = False, exclude_none: bool = False) -> 'DictStrAny':
-        return super().dict(include=include, exclude=exclude, by_alias=True, skip_defaults=skip_defaults, exclude_unset=exclude_unset, exclude_defaults=exclude_defaults, exclude_none=exclude_none)
-
     @staticmethod
     @abstractmethod
     def from_local_path(path: Union[Path, str]):
@@ -77,9 +92,6 @@ class Source(MessageElement):
     id: int
     time: int
 
-    def to_serialization(self) -> str:
-        return f"[mirai:source:{self.id},{self.time}]"
-
     @staticmethod
     def from_json(json: Dict) -> "Source":
         return Source.parse_obj(json)
@@ -100,7 +112,7 @@ class Quote(MessageElement):
         return MessageChain(v)
 
     def to_serialization(self) -> str:
-        return f" [mirai:quote:{self.id}]"
+        return f"[mirai:Quote:{{\"id\":{self.id},\"origin\":{self.origin}}}]"
 
     @staticmethod
     def from_json(json: Dict) -> "Quote":
@@ -146,10 +158,7 @@ class At(MessageElement):
         super().__init__(target=target, **kwargs)
 
     def to_text(self) -> str:
-        return str(self.display) if self.display else f"@{self.target}"
-
-    def to_serialization(self) -> str:
-        return f"[mirai:at:{self.target},{self.display}]"
+        return f'[@{str(self.display)} ]' if self.display else f"[@{self.target} ]"
 
     @staticmethod
     def from_json(json: Dict) -> "At":
@@ -161,10 +170,7 @@ class AtAll(MessageElement):
     type: str = "AtAll"
 
     def to_text(self) -> str:
-        return "@全体成员"
-
-    def to_serialization(self) -> str:
-        return "[mirai:atall]"
+        return "[@全体成员 ]"
 
     @staticmethod
     def from_json(json: Dict):
@@ -178,10 +184,7 @@ class Face(MessageElement):
     name: Optional[str] = None
 
     def to_text(self) -> str:
-        return "[表情]"
-
-    def to_serialization(self) -> str:
-        return f"[mirai:face:{self.faceId}]"
+        return f"[表情:{self.name}]" if self.name else f"[表情:{self.faceId}]"
 
     @staticmethod
     def from_json(json: Dict) -> "Face":
@@ -198,8 +201,8 @@ class Xml(MessageElement):
     def to_text(self) -> str:
         return "[XML消息]"
 
-    def to_serialization(self) -> str:
-        return f"[mirai:xml:{self.xml}]"
+    def get_xml(self):
+        return sax.parseString(self.xml, sax.handler.ContentHandler())
 
     @staticmethod
     def from_json(json: Dict):
@@ -215,14 +218,11 @@ class Json(MessageElement):
             json = JSON.dumps(json)
         super().__init__(json=json, **kwargs)
 
-    def dict(self, *args, **kwargs):
-        return super().dict(*args, **({**kwargs, "by_alias": True}))
-
     def to_text(self) -> str:
         return "[JSON消息]"
 
-    def to_serialization(self) -> str:
-        return f"[mirai:json:{self.Json}]"
+    def get_json(self) -> dict:
+        return JSON.loads(self.Json)
 
     @staticmethod
     def from_json(json: Dict):
@@ -234,10 +234,10 @@ class App(MessageElement):
     content: str
 
     def to_text(self) -> str:
-        return "[APP消息]"
+        return f"[APP消息:{JSON.loads(self.content)['prompt']}]"
 
-    def to_serialization(self) -> str:
-        return f"[mirai:app:{self.content}]"
+    def get_meta_content(self) -> dict:
+        return JSON.loads(self.content)['meta']
 
     @staticmethod
     def from_json(json: Dict):
@@ -270,9 +270,6 @@ class Poke(MessageElement):
     def to_text(self) -> str:
         return f"[戳一戳:{self.name}]"
 
-    def to_serialization(self) -> str:
-        return f"[mirai:poke:{self.name}]"
-
     @staticmethod
     def from_json(json: Dict):
         return Poke.parse_obj(json)
@@ -285,9 +282,6 @@ class Dice(MessageElement):
     def to_text(self) -> str:
         return f"[骰子:{self.value}]"
 
-    def to_serialization(self) -> str:
-        return f"[mirai:dice:{self.value}]"
-
     @staticmethod
     def from_json(json: Dict):
         return Dice.parse_obj(json)
@@ -302,9 +296,6 @@ class File(MessageElement):
     def to_text(self) -> str:
         return f'[文件:{self.name}]'
 
-    def to_serialization(self) -> str:
-        return f'[mirai:file:{self.name}]'
-
     @staticmethod
     def from_json(json: Dict):
         return File.parse_obj(json)
@@ -485,17 +476,40 @@ class MusicShare(MessageElement):
     def to_text(self) -> str:
         return f"[音乐分享:{self.title}]"
 
-    def to_serialization(self) -> str:
-        return f"[mirai:musicshare:{self.title}]"
-
     @staticmethod
     def from_json(json: Dict):
         return MusicShare.parse_obj(json)
 
 
+class ForwardNode(BaseModel):
+    """表示合并转发中的一个节点"""
+    senderId: int
+    time: int
+    senderName: str
+    messageChain: Optional["MessageChain"]
+    messageId: Optional[int]
+
+
+class Forward(MessageElement):
+    """
+    指示合并转发信息
+
+    nodeList (List[ForwardNode]): 转发的消息节点
+    """
+
+    type = "Forward"
+    nodeList: List[ForwardNode]
+
+    def to_text(self) -> str:
+        return f"[合并转发:共{len(self.nodeList)}条]"
+
+    @staticmethod
+    def from_json(json: Dict):
+        return Forward.parse_obj(json)
 
 
 def _update_forward_refs():
     from .messageChain import MessageChain
 
     Quote.update_forward_refs(MessageChain=MessageChain)
+    ForwardNode.update_forward_refs(MessageChain=MessageChain)
