@@ -2,8 +2,7 @@
 该文件为Cesloi的小型集成库
 """
 from .bot_client import Cesloi
-from .message import Friend
-from .message.group import Group, Member
+from .model.relation import Group, Member, Friend
 from .delegatesystem.entities.subsciber import SubscriberHandler
 from .communicate_with_mah import BotSession
 from .message.messageChain import MessageChain
